Documentation
¶
Overview ¶
package github.com/HPInc/krypton-dsts/service/cache Author: Mahesh Unnikrishnan Component: Krypton Device Security Token Service (C) HP Development Company, LP
package github.com/HPInc/krypton-dsts/service/cache Author: Mahesh Unnikrishnan Component: Krypton Device Security Token Service (C) HP Development Company, LP
package github.com/HPInc/krypton-dsts/service/cache Author: Mahesh Unnikrishnan Component: Krypton Device Security Token Service (C) HP Development Company, LP
package github.com/HPInc/krypton-dsts/service/cache Author: Mahesh Unnikrishnan Component: Krypton Device Security Token Service (C) HP Development Company, LP
package github.com/HPInc/krypton-dsts/service/cache Author: Mahesh Unnikrishnan Component: Krypton Device Security Token Service (C) HP Development Company, LP
Index ¶
- Variables
- func AddDevice(requestID string, deviceID string, device interface{})
- func AddDeviceAuthenticationChallenge(requestID string, deviceID string, challenge string) (time.Time, error)
- func AddEnrollmentToken(requestID string, token string, enrollment_token interface{})
- func AddRegisteredApp(requestID string, appID string, app interface{})
- func GetDevice(requestID string, deviceID string) ([]byte, error)
- func GetDeviceAuthenticationChallenge(requestID, deviceID string) (string, error)
- func GetEnrollmentTokenInfo(requestID string, token string) ([]byte, error)
- func GetRegisteredApp(requestID string, appID string) ([]byte, error)
- func Init(logger *zap.Logger, cfgMgr *config.ConfigMgr) error
- func RemoveDevice(requestID string, deviceID string)
- func RemoveEnrollmentToken(requestID string, tenantID string)
- func RemoveRegisteredApp(requestID string, appID string)
- func Shutdown()
Constants ¶
This section is empty.
Variables ¶
var (
ErrCacheNotFound = errors.New("item not found in cache")
)
Functions ¶
func AddDevice ¶
AddDevice - cache information about the specified device. This function is typically called from a goroutine and errors adding to the cache are not surfaced to the caller.
func AddDeviceAuthenticationChallenge ¶
func AddDeviceAuthenticationChallenge(requestID string, deviceID string, challenge string) (time.Time, error)
AddDeviceAuthenticationChallenge - Add the specified challenge code to the cache. The challenge code is later retrieved when completing the device authentication process.
func AddEnrollmentToken ¶
AddEnrollmentToken - Add a new enrollment token object to the cache.
func AddRegisteredApp ¶
AddRegisteredApp - cache information about the specified app. This function is typically called from a goroutine and errors adding to the cache are not surfaced to the caller.
func GetDeviceAuthenticationChallenge ¶
GetDeviceAuthenticationChallenge - Retrieve the specified challenge code from the cache. This is used when completing the device authentication process and verifying that the signed assertion presented by the client has a valid challenge code.
func GetEnrollmentTokenInfo ¶
GetEnrollmentToken - retrieve information about an enrollment token object from the cache.
func GetRegisteredApp ¶
GetRegisteredApp - retrieve information about a registered app from the cache.
func RemoveDevice ¶
RemoveDevice - remove cached information about the specified device. This function is typically called from within a goroutine and errors removing from the cache are not surfaced to the caller.
func RemoveEnrollmentToken ¶
RemoveEnrollmentToken - remove the cached enrollment token for the specified tenant. This function is typically called from within a goroutine and errors removing from the cache are not surfaced to the caller.
func RemoveRegisteredApp ¶
RemoveDevice - remove cached information about the specified app. This function is typically called from within a goroutine and errors removing from the cache are not surfaced to the caller.
Types ¶
This section is empty.